@@ -6,7 +6,6 @@ Create Date: 2020-10-31 12:47:09.284114
 
 """
 from alembic import op
-import sqlalchemy as sa
 
 
 # revision identifiers, used by Alembic.
@@ -26,7 +25,7 @@ def upgrade():
     acknowledged boolean generated always as ( ack_ts IS NOT NULL ) STORED,
     PRIMARY KEY (id),
     CONSTRAINT fk_tag FOREIGN KEY (tag_id) REFERENCES tags(id) ON DELETE CASCADE
-    );""")
+    );""")  # noqa: E501
     op.execute('ALTER TABLE tags ADD COLUMN battery_pct integer;')
     op.execute('ALTER TABLE tags ADD COLUMN distance_cm numeric(4,2);')
 
@@ -35,4 +34,3 @@ def downgrade():
     op.drop_table('alarms')
     op.execute('ALTER TABLE tags DROP COLUMN battery_pct')
     op.execute('ALTER TABLE tags DROP COLUMN distance_cm')
-
