@@ -9,8 +9,7 @@ from .schemas import prox_schema
 from .views import paginate_query
 from ..config import CONFIG
 
-THE_QUERY = \
-"""
+THE_QUERY = """
 SELECT tags.distance,
        zones.name as zone_name,
        tags.name as tag_name,
@@ -24,8 +23,7 @@ LEFT JOIN zones on zones.id = zone_id
 ORDER BY tags.id DESC
 """
 
-THE_TYPE_QUERY = \
-"""
+THE_TYPE_QUERY = """
 SELECT tags.distance,
        zones.name as zone_name,
        tags.name as tag_name,
@@ -40,8 +38,7 @@ WHERE tags.type = $1
 ORDER BY tags.id DESC
 """
 
-THE_GROUP_QUERY = \
-"""
+THE_GROUP_QUERY = """
 SELECT tags.distance,
        zones.name as zone_name,
        tags.name as tag_name,
@@ -55,16 +52,6 @@ LEFT JOIN zones on zones.id = zone_id
 WHERE tags.group_id = $1
 ORDER BY tags.id DESC
 """
-# """SELECT zones.name as zone_name, tags.name as tag_name, a.*
-# FROM (SELECT log.tag_id, zone_id, anchor_dist as distance, log.ts, anchor_id from log
-#     JOIN (SELECT tag_id, max(ts) max_ts from log WHERE anchor_id IS NOT NULL GROUP BY tag_id) temp
-#         ON log.tag_id = temp.tag_id AND log.ts = temp.max_ts
-# UNION SELECT DISTINCT ON (log.tag_id) log.tag_id, zone_id, distance_cm as distance, log.ts, anchor_id from log
-#     JOIN (SELECT tag_id, min(distance_cm), ts from log
-#           WHERE anchor_id IS NULL and ts > ((now() at time zone 'utc') - interval '1 min') GROUP BY tag_id, ts ORDER BY ts DESC) temp
-#     ON log.tag_id = temp.tag_id AND log.ts = temp.ts) a
-# LEFT JOIN zones on zone_id = zones.id
-# LEFT JOIN tags on tag_id = tags.id"""
 
 
 def process_prox_results(results):
@@ -99,32 +86,41 @@ class ProximityView(web.View, CorsViewMixin):
                 results = await conn.fetch(*query)
             except asyncpg.exceptions.InvalidTextRepresentationError:
                 raise web.HTTPBadRequest(text='Bad tag type in query')
-            return web.json_response(prox_schema.dump(process_prox_results(results)))
+            return web.json_response(
+                prox_schema.dump(process_prox_results(results)))
+
+
+PROXIMITY_TASK_QUERY = """
+UPDATE tags
+SET zone_id  = cf.zone_id,
+    distance = cf.distance
+FROM (SELECT DISTINCT ON (upper.tag_id) coalesce(anchor_dist, upper.distance) as distance,
+                                        upper.tag_id,
+                                        tags.zone_id
+      from log upper
+               LEFT JOIN tags on tags.id = upper.anchor_id
+      WHERE ts > tags.last_seen - interval '10s'
+      ORDER BY upper.tag_id, distance, upper.ts DESC) as cf
+WHERE tags.id = cf.tag_id
+"""  # noqa: E501
 
 
 async def proximity_task(pool):
-    query = """UPDATE tags SET zone_id = cf.zone_id, distance = cf.distance FROM
-(SELECT DISTINCT ON (upper.tag_id)
-    coalesce(anchor_dist, upper.distance) as distance,
-    upper.tag_id, tags.zone_id from log upper
-LEFT JOIN tags on tags.id = upper.anchor_id
-WHERE ts > tags.last_seen - interval '10s'
-ORDER BY upper.tag_id, distance, upper.ts DESC) as cf
-WHERE tags.id = cf.tag_id;
-"""
     period = CONFIG['LOCATION_UPDATE_MS'] / 1000
     count = 0
 
     while True:
         async with pool.acquire() as conn:
-            await conn.execute(query)
+            await conn.execute(PROXIMITY_TASK_QUERY)
             count += 1
             if count % 60 == 0:  # Once per minute
-                await conn.execute("DELETE FROM log WHERE ts < current_timestamp - interval '5m'")
+                await conn.execute(
+                    'DELETE FROM log '
+                    'WHERE ts < current_timestamp - interval \'5m\'')
             await asyncio.sleep(period)
 
 
-XML_TEMPLATE=jinja2.Template("""<?xml version="1.0" encoding="UTF-8"?>
+XML_TEMPLATE = jinja2.Template("""<?xml version="1.0" encoding="UTF-8"?>
 <TagData>
   {%- for tag in tags %}
   <Tag id="{{ tag.id }}">
@@ -142,8 +138,7 @@ XML_TEMPLATE=jinja2.Template("""<?xml version="1.0" encoding="UTF-8"?>
 </TagData>
 """)
 
-XML_QUERY = \
-"""
+XML_QUERY = """
 SELECT tags.distance,
        zones.name as zone_name,
        tags.name,
@@ -163,4 +158,6 @@ class ProximityXMLView(web.View, CorsViewMixin):
         results = None
         async with self.request.app['db_pool'].acquire() as conn:
             results = await conn.fetch(XML_QUERY)
-        return web.Response(text=XML_TEMPLATE.render(tags=results), content_type="text/xml", charset="utf-8")
\ No newline at end of file
+        return web.Response(
+            text=XML_TEMPLATE.render(tags=results), content_type="text/xml",
+            charset="utf-8")
