@@ -1,7 +1,7 @@
 import json
 import string
 
-from marshmallow import Schema, fields, validates
+from marshmallow import Schema, fields
 
 
 class JsonField(fields.Field):
@@ -22,7 +22,7 @@ class ListenerSchema(Schema, AttrsMixin):
     id = fields.Str(dump_only=True)
     name = fields.Str(allow_none=True)
     zone_id = fields.Int(allow_none=True)
-    last_seen = fields.DateTime(dump_only=True)
+    last_seen = fields.DateTime('%Y-%m-%dT%H:%M:%S+00:00', dump_only=True)
 
 
 class ZoneSchema(Schema, AttrsMixin):
@@ -60,11 +60,13 @@ class TagCreateBase(Schema, AttrsMixin):
     name = fields.Str(allow_none=True)
     zone_id = fields.Int(allow_none=True)
     group_id = fields.Int(allow_none=True)
-    last_seen = fields.DateTime(dump_only=True)
+    last_seen = fields.DateTime('%Y-%m-%dT%H:%M:%S+00:00', dump_only=True)
     type = fields.Str(required=True, validate=lambda x: x in {
-        'iBeacon', 'SmartRelay', 'LocationAnchor', 'SecureLocationAnchor', 'SecureSmartRelay'})
+        'iBeacon', 'SmartRelay', 'LocationAnchor', 'SecureLocationAnchor',
+        'SecureSmartRelay'})
     battery_pct = fields.Int(allow_none=True)
     alarm_active = fields.Boolean(allow_none=True)
+    zone_start = fields.DateTime('%Y-%m-%dT%H:%M:%S+00:00', dump_only=True)
 
 
 class iBeaconTagMixin:
@@ -103,7 +105,7 @@ class ProxSchema(Schema):
     tag_name = fields.Str(required=True)
     distance = fields.Float(required=True)
     zone_name = fields.Str(required=True)
-    last_seen = fields.DateTime(required=True)
+    last_seen = fields.DateTime('%Y-%m-%dT%H:%M:%S+00:00', required=True)
     tag_type = fields.Str(required=True)
     alarm_active = fields.Str(required=True)
     links = fields.Nested(ProxLinks)
@@ -118,8 +120,8 @@ class AlarmSchema(Schema):
     id = fields.Int(required=True)
     tag_name = fields.Str(required=True)
     zone_name = fields.Str(required=True)
-    start_ts = fields.DateTime(required=True)
-    last_ts = fields.DateTime(required=True)
+    start_ts = fields.DateTime('%Y-%m-%dT%H:%M:%S+00:00', required=True)
+    last_ts = fields.DateTime('%Y-%m-%dT%H:%M:%S+00:00', required=True)
     acknowledged = fields.Boolean(required=True)
     priority = fields.Int(required=True)
     links = fields.Nested(AlarmLinks)
@@ -130,8 +132,8 @@ class AlarmPatch(Schema):
 
 
 class HistorySchema(Schema):
-    start_ts = fields.DateTime(required=True)
-    end_ts = fields.DateTime(required=True)
+    start_ts = fields.DateTime('%Y-%m-%dT%H:%M:%S+00:00', required=True)
+    end_ts = fields.DateTime('%Y-%m-%dT%H:%M:%S+00:00', required=True)
     zone_id = fields.Int(required=True)
     zone_name = fields.Str(required=True)
     distance = fields.Float(required=True)
@@ -141,8 +143,8 @@ class HistorySchema(Schema):
 class ContactsSchema(Schema):
     tag_id = fields.Int(required=True)
     tag_name = fields.Str(required=True)
-    start_ts = fields.DateTime(required=True)
-    end_ts = fields.DateTime(required=True)
+    start_ts = fields.DateTime('%Y-%m-%dT%H:%M:%S+00:00', required=True)
+    end_ts = fields.DateTime('%Y-%m-%dT%H:%M:%S+00:00', required=True)
     duration = fields.TimeDelta(required=True)
     zone_id = fields.Int(required=True)
     zone_name = fields.Str(required=True)
@@ -168,4 +170,4 @@ alarms_schema = AlarmSchema(many=True)
 alarm_patch_schema = AlarmPatch()
 
 history_schema = HistorySchema(many=True)
-contacts_schema = ContactsSchema(many=True)
\ No newline at end of file
+contacts_schema = ContactsSchema(many=True)
