@@ -8,8 +8,10 @@ from dateutil.parser import isoparse
 from marshmallow import EXCLUDE
 import pytz
 
-from .schemas import (ibeacon_post_schema, macbeacon_post_schema, tag_patch_schema,
-                      history_schema, secure_beacon_post_schema, contacts_schema)
+from .schemas import (ibeacon_post_schema, macbeacon_post_schema,
+                      tag_patch_schema, history_schema, contacts_schema,
+                      secure_beacon_post_schema)
+from .sensors import format_sensors
 from .views import ValidatingView, paginate_query
 
 
@@ -41,7 +43,8 @@ class TagsView(ValidatingView):
                 tags = await conn.fetch(*query)
             except asyncpg.exceptions.InvalidTextRepresentationError:
                 raise web.HTTPBadRequest(text='Invalid tag type')
-            return web.json_response([tag_schema_dump(r) for r in tags if r is not None])
+            return web.json_response(
+                [tag_schema_dump(r) for r in tags if r is not None])
 
     async def post(self):
         body = await self._valid_json(self.request)
@@ -61,18 +64,21 @@ class TagsView(ValidatingView):
 
         async with self.request.app['db_pool'].acquire() as conn:
             try:
-                await conn.execute('INSERT INTO tags (mac, uuid, major, minor, type, zone_id, name, group_id, bid, attrs) VALUES '
-                                   '($1, $2, $3, $4, $5, $6, $7, $8, $9, $10)',
-                                   new_t.get('mac', None),
-                                   new_t.get('uuid', None),
-                                   new_t.get('major', None),
-                                   new_t.get('minor', None),
-                                   new_t['type'],
-                                   new_t.get('zone_id', None),
-                                   new_t.get('name', None),
-                                   new_t.get('group_id', None),
-                                   new_t.get('bid', None),
-                                   json.dumps(new_t.get('attrs', {})))
+                await conn.execute(
+                    'INSERT INTO tags '
+                    '(mac, uuid, major, minor, type, zone_id, name, '
+                    'group_id, bid, attrs) VALUES '
+                    '($1, $2, $3, $4, $5, $6, $7, $8, $9, $10)',
+                    new_t.get('mac', None),
+                    new_t.get('uuid', None),
+                    new_t.get('major', None),
+                    new_t.get('minor', None),
+                    new_t['type'],
+                    new_t.get('zone_id', None),
+                    new_t.get('name', None),
+                    new_t.get('group_id', None),
+                    new_t.get('bid', None),
+                    json.dumps(new_t.get('attrs', {})))
             except asyncpg.exceptions.UniqueViolationError as e:
                 raise web.HTTPConflict(reason=str(e.detail))
             except (asyncpg.exceptions.InvalidTextRepresentationError,
@@ -88,7 +94,8 @@ def parse_start_end(request):
         try:
             start = isoparse(request.query['start'])
         except ValueError:
-            raise web.HTTPBadRequest(reason="Invailid ISO8601 in start parameter")
+            raise web.HTTPBadRequest(
+                reason="Invailid ISO8601 in start parameter")
         if start.tzinfo:
             start = start.astimezone(utc).replace(tzinfo=None)
     else:
@@ -97,7 +104,8 @@ def parse_start_end(request):
         try:
             end = isoparse(request.query['end'])
         except ValueError:
-            raise web.HTTPBadRequest(reason="Invailid ISO8601 in end parameter")
+            raise web.HTTPBadRequest(
+                reason="Invailid ISO8601 in end parameter")
         if end.tzinfo:
             end = end.astimezone(utc).replace(tzinfo=None)
     else:
@@ -105,13 +113,8 @@ def parse_start_end(request):
     return start, end
 
 
-class TagHistoryView(web.View, CorsViewMixin):
-    async def get(self):
-        t_id = int(self.request.match_info['id'])
-        start, end = parse_start_end(self.request)
-        async with self.request.app['db_pool'].acquire() as conn:
-            query = (
-            """SELECT tag_id,
+HISTORY_QUERY = """
+SELECT tag_id,
        zone_id,
        start_ts,
        distance,
@@ -119,19 +122,23 @@ class TagHistoryView(web.View, CorsViewMixin):
        coalesce(end_ts, (now() at time zone 'utc')) - start_ts as duration
 FROM history
 WHERE tag_id = $1 AND start_ts >= $2 AND coalesce(end_ts, (now() at time zone 'utc')) <= $3
-ORDER BY start_ts DESC""", t_id, start, end)
+ORDER BY start_ts DESC
+"""  # noqa: E501
+
+
+class TagHistoryView(web.View, CorsViewMixin):
+    async def get(self):
+        t_id = int(self.request.match_info['id'])
+        start, end = parse_start_end(self.request)
+        async with self.request.app['db_pool'].acquire() as conn:
+            query = (HISTORY_QUERY, t_id, start, end)
             query = paginate_query(self.request, query)
             history = await conn.fetch(*query)
             return web.json_response(history_schema.dump(history))
 
 
-class TagContactView(web.View, CorsViewMixin):
-    async def get(self):
-        t_id = int(self.request.match_info['id'])
-        start, end = parse_start_end(self.request)
-        async with self.request.app['db_pool'].acquire() as conn:
-            query = (
-                """SELECT tag_id, tags.name, start_ts, end_ts, end_ts - start_ts as duration, b.zone_id, zone_name
+CONTACT_QUERY = """
+SELECT tag_id, tags.name as tag_name, start_ts, end_ts, end_ts - start_ts as duration, b.zone_id, zone_name
 FROM (
          WITH cte as (
              SELECT tag_id, start_ts, coalesce(end_ts, (now() at time zone 'utc')) as end_ts
@@ -147,32 +154,69 @@ FROM (
               cte
          WHERE history.start_ts >= $2 AND history.end_ts <= $3 AND (cte.start_ts, cte.end_ts) OVERLAPS (history.start_ts, history.end_ts)
            AND history.tag_id != $1
-     ) b JOIN tags on tags.id = tag_id""", t_id, start, end)
+     ) b JOIN tags on tags.id = tag_id"""  # noqa: E501
+
+
+async def tag_exists_or_404(t_id: int, conn) -> None:
+    tag_exists = await conn.fetchval(
+        "SELECT id from tags where id = $1", t_id)
+    if not tag_exists:
+        raise web.HTTPNotFound
+
+
+class TagContactView(web.View, CorsViewMixin):
+    async def get(self):
+        t_id = int(self.request.match_info['id'])
+        start, end = parse_start_end(self.request)
+        async with self.request.app['db_pool'].acquire() as conn:
+            await tag_exists_or_404(t_id, conn)
+            query = (CONTACT_QUERY, t_id, start, end)
             query = paginate_query(self.request, query)
             contacts = await conn.fetch(*query)
             return web.json_response(contacts_schema.dump(contacts))
 
 
+SENSORS_QUERY = """
+SELECT * FROM sensors
+WHERE tag_id = $1 AND ts >= $2 AND ts <= $3 ORDER BY ts DESC
+"""
+
+
+class TagSensorView(web.View, CorsViewMixin):
+    async def get(self):
+        t_id = int(self.request.match_info['id'])
+        start, end = parse_start_end(self.request)
+        async with self.request.app['db_pool'].acquire() as conn:
+            await tag_exists_or_404(t_id, conn)
+            query = (SENSORS_QUERY, t_id, start, end)
+            query = paginate_query(self.request, query)
+            sensors = await conn.fetch(*query)
+            return web.json_response(format_sensors(sensors))
+
+
 class TagView(ValidatingView):
     async def get(self):
         t_id = int(self.request.match_info['id'])
         async with self.request.app['db_pool'].acquire() as conn:
-            l = await conn.fetchrow('SELECT * FROM tags t WHERE id = $1', t_id)
-            if not l:
+            tag = await conn.fetchrow(
+                'SELECT * FROM tags t WHERE id = $1', t_id)
+            if not tag:
                 raise web.HTTPNotFound
-            return web.json_response(tag_schema_dump(l))
+            return web.json_response(tag_schema_dump(tag))
 
     async def patch(self):
         t_id = int(self.request.match_info['id'])
         async with self.request.app['db_pool'].acquire() as conn:
-            row = await conn.fetchrow('SELECT * FROM tags t WHERE id = $1', t_id)
+            row = await conn.fetchrow(
+                'SELECT * FROM tags t WHERE id = $1', t_id)
             if not row:
                 raise web.HTTPNotFound
             tag = dict(row.items())
             body = await self._valid_json(self.request)
             updates = self._validate(tag_patch_schema, body)
             if 'type' in updates:
-                del body['type']  # Ensure that we are validating against existing type
+                # Ensure that we are validating against existing type
+                del body['type']
             tag.update(updates)
             if tag['type'] in {'iBeacon', 'LocationAnchor'}:
                 self._validate(ibeacon_post_schema, tag, unknown=EXCLUDE)
@@ -181,11 +225,15 @@ class TagView(ValidatingView):
             elif tag['type'] in {'SecureSmartRelay', 'SecureLocationAnchor'}:
                 self._validate(secure_beacon_post_schema, tag, unknown=EXCLUDE)
             else:
-                raise web.HTTPBadRequest(reason=f'Unknown tag type {body["type"]}')
-            await conn.execute('UPDATE tags SET name = $1, mac = $2, uuid = $3, major = $4, '
-                               'minor = $5, attrs = $6, zone_id = $7, group_id = $8, bid = $9  WHERE id = $10',
-                               tag['name'], tag['mac'], tag['uuid'], tag['major'], tag['minor'],
-                               json.dumps(tag['attrs']), tag['zone_id'], tag['group_id'], tag['bid'], t_id)
+                raise web.HTTPBadRequest(
+                    reason=f'Unknown tag type {body["type"]}')
+            await conn.execute(
+                'UPDATE tags SET name = $1, mac = $2, uuid = $3, major = $4, '
+                'minor = $5, attrs = $6, zone_id = $7, group_id = $8, '
+                'bid = $9 WHERE id = $10', tag['name'], tag['mac'],
+                tag['uuid'], tag['major'], tag['minor'],
+                json.dumps(tag['attrs']), tag['zone_id'], tag['group_id'],
+                tag['bid'], t_id)
         raise web.HTTPNoContent
 
     async def delete(self):
