@@ -9,6 +9,7 @@ import jinja2
 app = web.Application()
 aiohttp_jinja2.setup(app, loader=jinja2.PackageLoader('c3loc', 'templates'))
 
+
 @aiohttp_jinja2.template('index.html')
 async def prox(request):
     return {}
@@ -33,6 +34,6 @@ app.router.add_static('/static/',
                       path=pkg_resources.resource_filename('c3loc', 'static'),
                       name='static')
 app.router.add_get('/', prox)
-app.router.add_get('/tags/{id:\d+}', tag_get)
-app.router.add_get('/zones/{id:\d+}', zone_get)
-app.router.add_get('/zones', add_zone)
+app.router.add_get(r'/tags/{id:\d+}', tag_get)
+app.router.add_get(r'/zones/{id:\d+}', zone_get)
+app.router.add_get(r'/zones', add_zone)
