@@ -4,9 +4,10 @@ import struct
 import attr
 from automat import MethodicalMachine
 
-HEADER_LEN = 5
 from ..config import CONFIG
 
+HEADER_LEN = 5
+
 
 @attr.s
 class RawMessage(object):
@@ -99,11 +100,13 @@ class Frame(object):
     @_machine.output()
     def _decompress_data(self):
         try:
-            d = lzo.decompress(bytes(self._data), False, 10240)  # 10kiB max payload
+            # 10kiB max payload
+            d = lzo.decompress(bytes(self._data), False,
+                               CONFIG['MAX_FRAME_SIZE'])
             self._data = d
             self._have_data()
         except lzo.error as e:
-            raise InvalidFrame('Failed to decompress data')
+            raise InvalidFrame(f'Failed to decompress data: {e}')
 
     @_machine.output()
     def _process_message(self):
@@ -129,12 +132,3 @@ class Frame(object):
                            outputs=[_decompress_data])
     _waiting_for_data.upon(_have_data, enter=_waiting_for_header,
                            outputs=[_process_message, _clear])
-
-
-def frame_message(data, compress=False):
-    from .protocol import PacketType
-    flags = (1 << 7) if compress else 0
-    flags |= PacketType.REQUEST
-    data = lzo.compress(data, 6, False) if compress else data
-    header = struct.pack("!IB", len(data), flags)
-    return b''.join([header, data])
