@@ -1,7 +1,6 @@
 #!/bin/env python
 """Reference Implementation of v1 C3 Security Beacon Auth Server."""
 import asyncio
-import asyncpg
 import os
 import signal
 
@@ -33,7 +32,7 @@ def main(port) -> None:
     start_packet_tasks()
 
     def start_server(loop):
-        return loop.create_server(ListenerProtocol, '0.0.0.0', port)
+        return loop.create_server(ListenerProtocol, '0.0.0.0', port)  # nosec
     server = loop.run_until_complete(start_server(loop))
     print("Listening on port {}".format(port))
     loop.run_forever()
